<?php

namespace Drupal\webform_reset_button\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\WebformEntityStorage;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class SettingsForm.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The webform storage service.
   *
   * @var \Drupal\webform\WebformEntityStorage
   */
  protected $webformStorage;

  /**
   * Constructs a SettingsForm object.
   *
   * @param \Drupal\webform\WebformEntityStorage $webform_storage
   *   The webform entity storage service.
   */
  public function __construct(WebformEntityStorage $webform_storage) {
    $this->webformStorage = $webform_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')->getStorage('webform')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['webform_reset_button.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webform_reset_button_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('webform_reset_button.settings');

    // Retrieve all Webforms.
    $webforms = $this->webformStorage->loadMultiple();
    $webform_options = [];

    foreach ($webforms as $webform) {
      $webform_options[$webform->id()] = $webform->label();
    }

    $enabled_webforms = $config->get('enabled_webforms');
    if (is_string($enabled_webforms)) {
      $enabled_webforms = explode(',', $enabled_webforms);
    }

    $form['enabled_webforms'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Webforms to Enable Reset Button'),
      '#description' => $this->t('Choose which Webforms should have the reset button enabled.'),
      '#options' => $webform_options,
      '#default_value' => $enabled_webforms,
      '#multiple' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $webform_ids = $form_state->getValue('enabled_webforms');

    $this->config('webform_reset_button.settings')
      ->set('enabled_webforms', $webform_ids)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
